searchData={"items":[{"type":"module","title":"TrailingZeros","doc":"A utility module for counting trailing zeros in the binary representation of integers.\n\nThis module provides efficient algorithms to count the number of consecutive zeros\nat the end of a number's binary representation. Trailing zeros are significant\nin various computational contexts, including:\n\n* **Bit manipulation**: Understanding the structure of binary numbers\n* **Performance optimization**: Some algorithms can be optimized based on trailing zero count\n* **Mathematical analysis**: Useful in number theory and discrete mathematics\n* **Memory alignment**: Important in low-level programming and system design","ref":"TrailingZeros.html"},{"type":"module","title":"Examples - TrailingZeros","doc":"iex> TrailingZeros.of(0)\n    0\n\n    iex> TrailingZeros.of(8)  # 8 = 1000 in binary\n    3\n\n    iex> TrailingZeros.of(12) # 12 = 1100 in binary\n    2\n\n    iex> TrailingZeros.of(7)  # 7 = 111 in binary\n    0","ref":"TrailingZeros.html#module-examples"},{"type":"module","title":"Algorithm - TrailingZeros","doc":"The implementation uses an efficient bit manipulation approach:\n\n1. **Base case**: Return 0 for input 0\n2. **Recursive counting**: Use bitwise operations to check the least significant bit\n3. **Bit shifting**: Right-shift the number to examine the next bit\n4. **Accumulation**: Count consecutive zeros until a 1 is encountered\n\nThe algorithm has O(log n) time complexity where n is the input number.","ref":"TrailingZeros.html#module-algorithm"},{"type":"module","title":"Performance - TrailingZeros","doc":"* **Time Complexity**: O(log n) - proportional to the number of bits\n* **Space Complexity**: O(1) - constant space usage\n* **Bitwise Operations**: Uses efficient `Bitwise.band/2` and `Bitwise.bsr/2`","ref":"TrailingZeros.html#module-performance"},{"type":"module","title":"Use Cases - TrailingZeros","doc":"* **Power of 2 detection**: Numbers with n trailing zeros are divisible by 2^n\n* **Binary number analysis**: Understanding the structure of binary representations\n* **Algorithm optimization**: Some divide-and-conquer algorithms benefit from this information\n* **Memory alignment**: Important for understanding data structure alignment requirements","ref":"TrailingZeros.html#module-use-cases"},{"type":"function","title":"TrailingZeros.of/1","doc":"Counts the number of trailing zeros in the binary representation of a non-negative integer.\n\nReturns the count of consecutive zeros at the end of the number's binary representation.\nFor example, the binary representation of 8 is 1000, which has 3 trailing zeros.","ref":"TrailingZeros.html#of/1"},{"type":"function","title":"Parameters - TrailingZeros.of/1","doc":"* `n` - A non-negative integer to analyze","ref":"TrailingZeros.html#of/1-parameters"},{"type":"function","title":"Returns - TrailingZeros.of/1","doc":"* `non_neg_integer()` - The number of trailing zeros in the binary representation","ref":"TrailingZeros.html#of/1-returns"},{"type":"function","title":"Examples - TrailingZeros.of/1","doc":"iex> TrailingZeros.of(0)\n    0\n\n    iex> TrailingZeros.of(1)  # 1 = 1 in binary\n    0\n\n    iex> TrailingZeros.of(2)  # 2 = 10 in binary\n    1\n\n    iex> TrailingZeros.of(4)  # 4 = 100 in binary\n    2\n\n    iex> TrailingZeros.of(8)  # 8 = 1000 in binary\n    3\n\n    iex> TrailingZeros.of(12) # 12 = 1100 in binary\n    2\n\n    iex> TrailingZeros.of(16) # 16 = 10000 in binary\n    4\n\n    iex> TrailingZeros.of(1024) # 1024 = 10000000000 in binary\n    10","ref":"TrailingZeros.html#of/1-examples"},{"type":"function","title":"Edge Cases - TrailingZeros.of/1","doc":"iex> TrailingZeros.of(0)  # Zero has no trailing zeros\n    0\n\n    iex> TrailingZeros.of(255) # 255 = 11111111 in binary\n    0\n\n    iex> TrailingZeros.of(256) # 256 = 100000000 in binary\n    8","ref":"TrailingZeros.html#of/1-edge-cases"},{"type":"function","title":"Mathematical Properties - TrailingZeros.of/1","doc":"* For any number n, if `TrailingZeros.of(n) = k`, then n is divisible by 2^k\n* Powers of 2 have trailing zero counts equal to their exponent\n* Odd numbers always have 0 trailing zeros\n* The maximum trailing zeros for a 32-bit integer is 31 (for 0)","ref":"TrailingZeros.html#of/1-mathematical-properties"},{"type":"function","title":"Algorithm Details - TrailingZeros.of/1","doc":"The function uses a recursive approach with bitwise operations:\n\n1. **Base case**: Returns 0 for input 0\n2. **Recursive step**: \n   - Check if the least significant bit is 1 using `Bitwise.band(x, 1)`\n   - If 1 is found, return the accumulated count\n   - If 0 is found, right-shift by 1 and increment the accumulator\n3. **Termination**: Guaranteed to terminate as the number decreases with each shift","ref":"TrailingZeros.html#of/1-algorithm-details"},{"type":"function","title":"Performance Characteristics - TrailingZeros.of/1","doc":"* **Time Complexity**: O(log n) - proportional to the number of bits in the input\n* **Space Complexity**: O(1) - constant space usage (tail-recursive)\n* **Bitwise Operations**: Uses efficient bitwise AND and right shift operations","ref":"TrailingZeros.html#of/1-performance-characteristics"},{"type":"extras","title":"Trailing Zeros","doc":"# Trailing Zeros\n\n[![Build Status](https://github.com/TODO/trailing_zeros/workflows/CI/badge.svg)](https://github.com/TODO/trailing_zeros/actions)\n[![Hex.pm](https://img.shields.io/hexpm/v/trailing_zeros.svg)](https://hex.pm/packages/trailing_zeros)\n[![Hex.pm](https://img.shields.io/hexpm/dt/trailing_zeros.svg)](https://hex.pm/packages/trailing_zeros)\n[![License](https://img.shields.io/hexpm/l/trailing_zeros.svg)](https://github.com/TODO/trailing_zeros/blob/main/LICENSE.md)\n\nA fast and efficient Elixir library for counting trailing zeros in the binary representation of integers.","ref":"readme.html"},{"type":"extras","title":"Features - Trailing Zeros","doc":"- **High Performance**: O(log n) time complexity using optimized bitwise operations\n- **Memory Efficient**: O(1) space complexity with tail-recursive implementation\n- **Comprehensive Testing**: 14 test cases covering edge cases and typical scenarios\n- **Well Documented**: Complete documentation with examples and use cases\n- **Type Safe**: Full type specifications for better development experience","ref":"readme.html#features"},{"type":"extras","title":"Installation - Trailing Zeros","doc":"Add `trailing_zeros` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:trailing_zeros, \"~> 1.0\"}\n  ]\nend\n```\n\nThen install dependencies:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Trailing Zeros","doc":"```elixir\n# Count trailing zeros in binary representation\nTrailingZeros.of(0)    # Returns: 0\nTrailingZeros.of(8)    # Returns: 3 (8 = 1000 in binary)\nTrailingZeros.of(12)   # Returns: 2 (12 = 1100 in binary)\nTrailingZeros.of(16)   # Returns: 4 (16 = 10000 in binary)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Algorithm - Trailing Zeros","doc":"The library uses an efficient bit manipulation approach:\n\n1. **Base case**: Return 0 for input 0\n2. **Recursive counting**: Use bitwise operations to check the least significant bit\n3. **Bit shifting**: Right-shift the number to examine the next bit\n4. **Accumulation**: Count consecutive zeros until a 1 is encountered","ref":"readme.html#algorithm"},{"type":"extras","title":"Performance Characteristics - Trailing Zeros","doc":"- **Time Complexity**: O(log n) - proportional to the number of bits\n- **Space Complexity**: O(1) - constant space usage (tail-recursive)\n- **Bitwise Operations**: Uses efficient `Bitwise.band/2` and `Bitwise.bsr/2`","ref":"readme.html#performance-characteristics"},{"type":"extras","title":"Mathematical Properties - Trailing Zeros","doc":"- For any number n, if `TrailingZeros.of(n) = k`, then n is divisible by 2^k\n- Powers of 2 have trailing zero counts equal to their exponent\n- Odd numbers always have 0 trailing zeros\n- The maximum trailing zeros for a 32-bit integer is 31 (for 0)","ref":"readme.html#mathematical-properties"},{"type":"extras","title":"License - Trailing Zeros","doc":"Copyright (c) 2025 University of Kitakyushu\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog - Trailing Zeros","doc":"See [CHANGELOG.md](CHANGELOG.md) for a list of changes and version history.","ref":"readme.html#changelog"},{"type":"extras","title":"Acknowledgments - Trailing Zeros","doc":"- Built with modern Elixir development practices\n- Uses efficient bitwise operations for optimal performance\n- Comprehensive test coverage ensures reliability\n- Well-documented for easy integration and learning","ref":"readme.html#acknowledgments"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.0.0] - 2025-07-21","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial project setup with comprehensive development tooling\n- Complete test suite with 14 test cases covering edge cases and typical scenarios\n- Full documentation with examples and use cases\n- Performance optimization with O(log n) time complexity\n- Type specifications for better development experience\n- **Core Functionality**: `TrailingZeros.of/1` function for counting trailing zeros\n- **Algorithm Implementation**: Efficient bit manipulation approach using `Bitwise` operations\n- **Performance Optimization**: O(log n) time complexity with O(1) space complexity\n- **Type Safety**: Full type specifications with `@spec` annotations\n- **Comprehensive Testing**: 14 test cases covering:\n  - Edge cases (0, maximum 32-bit integer)\n  - Powers of 2 (2^0 through 2^30)\n  - Odd numbers and mixed patterns\n  - Large numbers and boundary conditions\n  - Alternating bit patterns and specific structures","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Enhanced project configuration with modern Elixir development practices\n- Improved code quality checks with comprehensive tooling\n- Updated documentation structure for better maintainability","ref":"changelog.html#changed"},{"type":"extras","title":"Features - Changelog","doc":"- **High Performance**: Optimized bitwise operations for maximum efficiency\n- **Memory Efficient**: Tail-recursive implementation with constant space usage\n- **Mathematical Accuracy**: Correct handling of all edge cases and mathematical properties\n- **Developer Friendly**: Clear documentation with extensive examples","ref":"changelog.html#features"},{"type":"extras","title":"Documentation - Changelog","doc":"- **Module Documentation**: Comprehensive `@moduledoc` with algorithm explanation\n- **Function Documentation**: Detailed `@doc` with parameters, returns, and examples\n- **Performance Analysis**: Time and space complexity documentation\n- **Use Cases**: Practical examples for power of 2 detection, binary analysis, and memory alignment\n- **Mathematical Properties**: Theoretical background and relationships","ref":"changelog.html#documentation"},{"type":"extras","title":"Development Tooling - Changelog","doc":"- **Code Quality**: Credo static analysis with custom configuration\n- **Type Checking**: Dialyzer integration for type safety\n- **Documentation**: ExDoc setup for generated documentation\n- **Spell Checking**: Spellweaver integration for documentation quality\n- **Formatting**: Consistent code formatting with migration support\n- **Dependency Management**: Comprehensive dependency audit and version locking","ref":"changelog.html#development-tooling"},{"type":"extras","title":"Project Structure - Changelog","doc":"- **License**: Apache 2.0 license with University of Kitakyushu copyright\n- **README**: Comprehensive documentation with installation, usage, and development instructions\n- **Package Configuration**: Proper Hex.pm metadata and GitHub integration\n- **Version Management**: Semantic versioning with proper changelog structure","ref":"changelog.html#project-structure"},{"type":"extras","title":"Technical Implementation - Changelog","doc":"- **Base Case**: Proper handling of input 0\n- **Recursive Algorithm**: Efficient bitwise AND and right shift operations\n- **Accumulator Pattern**: Tail-recursive implementation for optimal performance\n- **Bitwise Operations**: Uses `Bitwise.band/2` and `Bitwise.bsr/2` for efficiency\n- **Termination Guarantee**: Algorithm guaranteed to terminate as number decreases with each shift","ref":"changelog.html#technical-implementation"},{"type":"extras","title":"Mathematical Properties Supported - Changelog","doc":"- For any number n, if `TrailingZeros.of(n) = k`, then n is divisible by 2^k\n- Powers of 2 have trailing zero counts equal to their exponent\n- Odd numbers always have 0 trailing zeros\n- Maximum trailing zeros for 32-bit integer is 31 (for 0)","ref":"changelog.html#mathematical-properties-supported"},{"type":"extras","title":"Performance Characteristics - Changelog","doc":"- **Time Complexity**: O(log n) - proportional to number of bits in input\n- **Space Complexity**: O(1) - constant space usage with tail recursion\n- **Bitwise Efficiency**: Optimized use of bitwise operations\n- **Memory Usage**: Minimal memory footprint with no additional data structures","ref":"changelog.html#performance-characteristics"},{"type":"extras","title":"Use Cases Demonstrated - Changelog","doc":"- **Power of 2 Detection**: Numbers with n trailing zeros are divisible by 2^n\n- **Binary Number Analysis**: Understanding structure of binary representations\n- **Memory Alignment**: Important for data structure alignment requirements\n- **Algorithm Optimization**: Useful in divide-and-conquer algorithms\n\n---","ref":"changelog.html#use-cases-demonstrated"},{"type":"extras","title":"Version History Summary - Changelog","doc":"","ref":"changelog.html#version-history-summary"},{"type":"extras","title":"Major Versions - Changelog","doc":"- **v1.0.0**: First stable release with complete functionality","ref":"changelog.html#major-versions"},{"type":"extras","title":"Development Phases - Changelog","doc":"1. **Project Initialization**: Basic Elixir application structure\n2. **Core Implementation**: Trailing zeros algorithm with bitwise operations\n3. **Testing & Quality**: Comprehensive test suite and code quality tools\n4. **Documentation**: Complete documentation with examples and use cases\n5. **Release Preparation**: Package configuration and deployment readiness","ref":"changelog.html#development-phases"},{"type":"extras","title":"Key Milestones - Changelog","doc":"- ✅ Core algorithm implementation\n- ✅ Comprehensive test coverage\n- ✅ Complete documentation\n- ✅ Development tooling integration\n- ✅ Performance optimization\n- ✅ Type safety implementation\n- ✅ Package configuration\n- ✅ Release preparation\n\n---","ref":"changelog.html#key-milestones"},{"type":"extras","title":"Contributing to Changelog - Changelog","doc":"When adding entries to this changelog, please follow these guidelines:\n\n1. **Use the existing format** and structure\n2. **Group changes** by type (Added, Changed, Fixed, etc.)\n3. **Be descriptive** but concise\n4. **Include version numbers** and dates for releases\n5. **Follow semantic versioning** for version numbers\n6. **Update both Unreleased and version-specific sections** as needed","ref":"changelog.html#contributing-to-changelog"},{"type":"extras","title":"Links - Changelog","doc":"- [GitHub Repository](https://github.com/zacky1972/trailing_zeros)\n- [Hex Package](https://hex.pm/packages/trailing_zeros)\n- [Documentation](https://hexdocs.pm/trailing_zeros)\n- [Issues](https://github.com/zacky1972/trailing_zeros/issues)","ref":"changelog.html#links"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}